module.exports = defineTest({
	description: 'Preserves asm.js code (#3360)'
});
